aboutsummaryrefslogtreecommitdiffstats
path: root/python/servo/command_base.py
diff options
context:
space:
mode:
authoratouchet <alextouchet@outlook.com>2020-05-27 20:13:15 -0700
committeratouchet <alextouchet@outlook.com>2020-05-27 20:27:15 -0700
commita33c75cbecb10dd6aa80289b2a35c18db207652b (patch)
tree11a2cbf5883e25f90f065c0c4d84b4c88512a536 /python/servo/command_base.py
parent693ff298582d3037afd145563c234ef5ceb6d42b (diff)
downloadservo-a33c75cbecb10dd6aa80289b2a35c18db207652b.tar.gz
servo-a33c75cbecb10dd6aa80289b2a35c18db207652b.zip
Rename glutin port to winit
Diffstat (limited to 'python/servo/command_base.py')
-rw-r--r--python/servo/command_base.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/python/servo/command_base.py b/python/servo/command_base.py
index 65619102a7d..e3942ef66e0 100644
--- a/python/servo/command_base.py
+++ b/python/servo/command_base.py
@@ -696,7 +696,7 @@ install them, let us know by filing a bug!")
# These are set because they are the variable names that build-apk
# expects. However, other submodules have makefiles that reference
# the env var names above. Once glutin is enabled and set as the
# default, we could modify the subproject makefiles to use the names
# below and remove the vars above, to avoid duplication.
if "ANDROID_SDK" in env:
@@ -869,7 +869,7 @@ install them, let us know by filing a bug!")
api = "capi"
port = path.join("libsimpleservo", api)
else:
- port = "glutin"
+ port = "winit"
args += [
"--manifest-path",
path.join(self.context.topdir, "ports", port, "Cargo.toml"),
@@ -696,7 +696,7 @@ install them, let us know by filing a bug!")
# These are set because they are the variable names that build-apk
# expects. However, other submodules have makefiles that reference
- # the env var names above. Once glutin is enabled and set as the
+ # the env var names above. Once winit is enabled and set as the
# default, we could modify the subproject makefiles to use the names
# below and remove the vars above, to avoid duplication.